#include "netstat.h"
 
#include <QtCore> 
#include "plasma/datacontainer.h"
#include <solid/devicenotifier.h>
#include <solid/device.h>
#include <solid/networkinterface.h>
 
NetStatEngine::NetStatEngine(QObject* parent, const QVariantList&)
    : Plasma::DataEngine(parent)
{
   updateSourceEvent("NCs");
   Solid::DeviceNotifier * dn = Solid::DeviceNotifier::instance();
   dn->connect(dn, SIGNAL(deviceAdded(const QString)), this, SLOT(updateDevices()));
   dn->connect(dn, SIGNAL(deviceRemoved(const QString)), this, SLOT(updateDevices()));
}
 
bool NetStatEngine::sourceRequestEvent(const QString &name)
{
    return updateSourceEvent(name);
}

bool NetStatEngine::updateSourceEvent(const QString &name)
{
  if (name == "NCs") {
    QList<Solid::Device> devlist = Solid::Device::listFromType(Solid::DeviceInterface::NetworkInterface, QString());
    QStringList sl;
    foreach (const Solid::Device &device, devlist) {
      sl << "Device: " + device.parent().product();
      Solid::NetworkInterface * ni = (Solid::NetworkInterface *) device.asDeviceInterface(Solid::DeviceInterface::NetworkInterface);
      sl << "Interface: " + ni->ifaceName();
      sl << "Address: " + ni->hwAddress();
       //sl << "Adress: " + ni->macAddress();
     sl << QString("Type: ") + (ni->isWireless() ? "Wireless" : "Wired");
    }
    setData(name, sl);
    return true;
  } 
  return false;
}

void NetStatEngine::updateDevices()
{
  updateSourceEvent("NCs"); 
}
 
K_EXPORT_PLASMA_DATAENGINE(netstat, NetStatEngine)
 
#include "netstat.moc" 
